@@ -55,7 +55,7 @@
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "5.1.2"
+#define GM_VERSION                 "5.1.2.20230624"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               65536
@@ -224,7 +224,6 @@ typedef struct mod_gm_opt_struct {
     int            orphan_service_checks;                   /**< generate fake result for orphaned service checks */
     int            accept_clear_results;                    /**< accept unencrypted results */
     int            latency_flatten_window;                  /**< postpone high latency checks */
-    int            internal_check_dummy;                    /**< handle check_dummy checks internally */
 /* worker */
     char         * identifier;                              /**< identifier for this worker */
     char         * pidfile;                                 /**< path to a pidfile */
